@@ -6,36 +6,47 @@
 :License: MIT
 """
 
+from .exceptions import SkippedTestCaseException  # noqa: F401
+from biosimulators_utils.image import get_docker_image
 import abc
+import docker
 import enum
 
-__all__ = ['AbstractTestCase', 'SedTaskRequirements', 'ExpectedSedReport', 'ExpectedSedPlot',
-           'TestCaseResultType', 'TestCaseResult',
-           'AlertType',
-           'InvalidOuputsException', 'InvalidOuputsWarning',
-           'SkippedTestCaseException', 'IgnoredTestCaseWarning',
-           ]
+__all__ = [
+    'OutputMedium',
+    'TestCase', 'SedTaskRequirements', 'ExpectedSedReport', 'ExpectedSedPlot',
+    'AlertType',
+]
 
 
-class AbstractTestCase(abc.ABC):
+class OutputMedium(str, enum.Enum):
+    """ Output medium """
+    console = 'console'
+    gh_issue = 'gh_issue'
+
+
+class TestCase(abc.ABC):
     """ A test case for validating a simulator
 
     Attributes:
         id (:obj:`str`): id
         name (:obj:`str`): name
         description (:obj:`str`): description
+        output_medium (:obj:`OutputMedium`): medium the description should be formatted for
     """
 
-    def __init__(self, id=None, name=None, description=None):
+    def __init__(self, id=None, name=None, description=None, output_medium=OutputMedium.console):
         """
         Args:
             id (:obj:`str`, optional): id
             name (:obj:`str`, optional): name
             description (:obj:`str`): description
+            output_medium (:obj:`OutputMedium`, optional): medium the description should be formatted
         """
         self.id = id
         self.name = name
         self.description = description
+        self.output_medium = output_medium
 
     @abc.abstractmethod
     def eval(self, specifications):
@@ -50,6 +61,19 @@ class AbstractTestCase(abc.ABC):
         """
         pass  # pragma: no cover
 
+    def get_simulator_docker_image(self, specifications, pull=True):
+        """ Get the Docker image for a simulator, pulling if necessary
+
+        Args:
+            specifications (:obj:`dict`): specifications of the simulator to validate
+
+        Returns:
+            :obj:`docker.models.images.Image`: Docker image
+        """
+        docker_client = docker.from_env()
+        image_url = specifications['image']['url']
+        return get_docker_image(docker_client, image_url, pull=pull)
+
 
 class SedTaskRequirements(object):
     """ Required model format for simulation algorithm for each task in a SED document
@@ -108,61 +132,7 @@ class ExpectedSedPlot(object):
         self.id = id
 
 
-class TestCaseResultType(str, enum.Enum):
-    """ Type of test case result """
-    passed = 'passed'
-    failed = 'failed'
-    skipped = 'skipped'
-
-
-class TestCaseResult(object):
-    """ A result of executing a test case
-
-    Attributes:
-        case (:obj:`TestCase`): test case
-        type (:obj:`obj:`TestCaseResultType`): type
-        duration (:obj:`float`): execution duration in seconds
-        exception (:obj:`Exception`): exception
-        log (:obj:`str`): log of execution
-    """
-
-    def __init__(self, case=None, type=None, duration=None, exception=None, log=None):
-        """
-        Args:
-            case (:obj:`TestCase`, optional): test case
-            type (:obj:`obj:`TestCaseResultType`, optional): type
-            duration (:obj:`float`, optional): execution duration in seconds
-            exception (:obj:`Exception`, optional): exception
-            log (:obj:`str`, optional): log of execution
-        """
-        self.case = case
-        self.type = type
-        self.duration = duration
-        self.exception = exception
-        self.log = log
-
-
 class AlertType(str, enum.Enum):
     """ Type of alert upon the failure of a test case """
     exception = 'exception'
     warning = 'warning'
-
-
-class InvalidOuputsException(Exception):
-    """ Exception raised when outputs of execution of COMBINE/OMEX archive are not as expected """
-    pass  # pragma: no cover
-
-
-class InvalidOuputsWarning(UserWarning):
-    """ Warning raised when outputs of execution of COMBINE/OMEX archive are not as expected """
-    pass  # pragma: no cover
-
-
-class SkippedTestCaseException(Exception):
-    """ Exception raised that indicates that a test case should be skipped """
-    pass  # pragma: no cover
-
-
-class IgnoredTestCaseWarning(UserWarning):
-    """ Warning raised that indicates that a test case was ignored """
-    pass  # pragma: no cover
