@@ -7,13 +7,17 @@
 :License: MIT
 """
 
-from .data_model import TestCaseResultType
+from .data_model import OutputMedium
 from .exec_core import SimulatorValidator
+from .results.data_model import TestCaseResult, TestCaseResultType, TestResultsReport  # noqa: F401
+from .results.io import write_test_results
 from biosimulators_utils.gh_action.data_model import Comment, GitHubActionCaughtError  # noqa: F401
 from biosimulators_utils.gh_action.core import GitHubAction, GitHubActionErrorHandling
+from biosimulators_utils.image import get_docker_image
 from biosimulators_utils.simulator_registry.data_model import SimulatorSubmission, IssueLabel  # noqa: F401
 from biosimulators_utils.simulator_registry.process_submission import get_simulator_submission_from_gh_issue_body
 from biosimulators_utils.simulator_registry.query import get_simulator_version_specs
+
 from natsort import natsort_keygen
 import biosimulators_utils.image
 import biosimulators_utils.simulator.io
@@ -56,8 +60,8 @@ class ValidateCommitSimulatorGitHubAction(GitHubAction):
         issue_number (:obj:`str`): number of GitHub issue which triggered the action
     """
     BIOSIMULATORS_AUTH_ENDPOINT = 'https://auth.biosimulations.org/oauth/token'
-    BIOSIMULATORS_AUDIENCE = 'api.biosimulators.org'
-    BIOSIMULATORS_API_ENDPOINT = 'https://api.biosimulators.org/'
+    BIOSIMULATORS_AUDIENCE = os.getenv('BIOSIMULATORS_AUDIENCE', 'api.biosimulators.org')
+    BIOSIMULATORS_API_ENDPOINT = os.getenv('BIOSIMULATORS_API_ENDPOINT', 'https://api.biosimulators.org/')
     DOCKER_REGISTRY_URL = 'ghcr.io'
     DOCKER_REGISTRY_IMAGE_URL_PATTERN = 'ghcr.io/biosimulators/{}:{}'
     DEFAULT_SPECIFICATIONS_VERSION = '1.0.0'
@@ -86,7 +90,7 @@ class ValidateCommitSimulatorGitHubAction(GitHubAction):
         self.reset_issue_labels(self.issue_number, [IssueLabel.validated.value, IssueLabel.invalid.value, IssueLabel.action_error.value])
 
         # get specifications of simulator and validate simulator
-        specifications = self.exec_core(submission)
+        specifications, test_results = self.exec_core(submission)
 
         # label issue as validated
         self.add_labels_to_issue(self.issue_number, [IssueLabel.validated.value])
@@ -105,7 +109,7 @@ class ValidateCommitSimulatorGitHubAction(GitHubAction):
         # commit simulator or indicate that further review is required
         if submission.commit_simulator:
             if approved:
-                self.commit_simulator(submission, specifications, existing_version_specifications)
+                self.commit_simulator(submission, specifications, existing_version_specifications, test_results)
 
                 # post success message
                 self.add_comment_to_issue(
@@ -174,7 +178,10 @@ class ValidateCommitSimulatorGitHubAction(GitHubAction):
             submission (:obj:`SimulatorSubmission`): simulator submission
 
         Returns:
-            :obj:`dict`: specifications of a simulation tool
+            :obj:`tuple`:
+
+                * :obj:`dict`: specifications of a simulation tool
+                * :obj:`list` of :obj:`TestCaseResults`: results of test cases
         """
         # validate specifications
         specifications = biosimulators_utils.simulator.io.read_simulator_specs(
@@ -183,17 +190,22 @@ class ValidateCommitSimulatorGitHubAction(GitHubAction):
 
         # validate image
         if submission.validate_image:
-            self.validate_image(specifications)
+            test_results = self.validate_image(specifications)
             self.add_comment_to_issue(self.issue_number, 'The image for your simulator is valid!')
+        else:
+            test_results = None
 
         # return specifications
-        return specifications
+        return specifications, test_results
 
     def validate_image(self, specifications):
         """ Validate a Docker image for simulation tool
 
         Args:
             specifications (:obj:`dict`): specifications of a simulation tool
+
+        Returns:
+            :obj:`list` of :obj:`TestCaseResults`: results of test cases
         """
         docker_client = biosimulators_utils.image.login_to_docker_registry(
             'docker.io',
@@ -202,18 +214,21 @@ class ValidateCommitSimulatorGitHubAction(GitHubAction):
 
         # validate that container (Docker image) exists
         image_url = specifications['image']['url']
-        biosimulators_utils.image.pull_docker_image(docker_client, image_url)
+        get_docker_image(docker_client, image_url, pull=True)
 
         # validate that Docker image can be converted to a Singularity image
         biosimulators_utils.image.convert_docker_image_to_singularity(image_url)
 
         # validate that image is consistent with the BioSimulators standards
-        validator = SimulatorValidator()
-        case_results = validator.run(specifications)
-        summary, failure_details = validator.summarize_results(case_results)
-        msg = '## Summary\n{}'.format(summary)
+        validator = SimulatorValidator(specifications, output_medium=OutputMedium.gh_issue)
+        case_results = validator.run()
+        write_test_results(case_results, '.biosimulators-test-suite-results.json')
+        summary, failure_details, warning_details = validator.summarize_results(case_results)
+        msg = '## Summary of tests\n\n{}\n\n'.format(summary)
         if failure_details:
-            msg += '\n## Failures\n{}'.format(failure_details)
+            msg += '\n## Failures\n\n{}\n\n'.format('### ' + '\n### '.join(failure_details))
+        if warning_details:
+            msg += '\n## Warnings\n\n{}\n\n'.format('### ' + '\n### '.join(warning_details))
         self.add_comment_to_issue(self.issue_number, msg)
 
         invalid_cases = [case_result for case_result in case_results if case_result.type == TestCaseResultType.failed]
@@ -221,7 +236,8 @@ class ValidateCommitSimulatorGitHubAction(GitHubAction):
             error_msg = 'After correcting your simulator, please edit the first block of this issue to re-initiate this validation.'
             self.add_error_comment_to_issue(self.issue_number, [Comment(text=error_msg, error=True)])
 
-        valid_cases = [case_result for case_result in case_results if case_result.type == TestCaseResultType.passed]
+        valid_cases = [case_result for case_result in case_results
+                       if case_result.type == TestCaseResultType.passed and case_result.case.id.startswith('sedml.')]
         if not valid_cases:
             self.add_error_comment_to_issue(self.issue_number, [Comment(text=(
                 'No test cases are applicable to your simulator. '
@@ -229,6 +245,8 @@ class ValidateCommitSimulatorGitHubAction(GitHubAction):
                 'The BioSimulators Team will add these files to this validation program and then re-review your simulator.'
             ))])
 
+        return case_results
+
     def is_simulator_approved(self, specifications, existing_version_specifications):
         """ Determine whether a simulation tool has already been approved
 
@@ -266,23 +284,33 @@ class ValidateCommitSimulatorGitHubAction(GitHubAction):
                 return True
         return False
 
-    def commit_simulator(self, submission, specifications, existing_version_specifications):
+    def commit_simulator(self, submission, specifications, existing_version_specifications, test_results):
         """ Commit simulator to the BioSimulators registry
 
         Args:
             submission (:obj:`SimulatorSubmission`): simulator submission
             specifications (:obj:`dict`): specifications of a simulation tool
             existing_version_specifications (:obj:`list` of :obj:`dict`): specifications of other versions of simulation tool
+            test_results (:obj:`list` of :obj:`TestCaseResults`): results of test cases
         """
         # copy image to BioSimulators namespace of Docker registry (GitHub Container Registry)
         if submission.validate_image:
             self.push_image(specifications, existing_version_specifications)
 
         # commit submission to BioSimulators database
+        if 'biosimulators' not in specifications:
+            specifications['biosimulators'] = {}
+
         if submission.validate_image:
-            if 'biosimulators' not in specifications:
-                specifications['biosimulators'] = {}
             specifications['biosimulators']['validated'] = True
+            specifications['biosimulators']['validationTests'] = TestResultsReport(
+                results=test_results, gh_issue=int(self.issue_number), gh_action_run=int(self.get_gh_action_run_id()),
+            ).to_dict()
+
+        else:
+            specifications['biosimulators']['validated'] = False
+            specifications['biosimulators']['validationTests'] = None
+
         self.post_entry_to_biosimulators_api(specifications, existing_version_specifications)
 
     def push_image(self, specifications, existing_version_specifications):
@@ -292,13 +320,13 @@ class ValidateCommitSimulatorGitHubAction(GitHubAction):
             specifications (:obj:`dict`): specifications of a simulation tool
             existing_version_specifications (:obj:`list` of :obj:`dict`): specifications of other versions of simulation tool
         """
-        # pull image
+        # get image, pulling if necessary
         original_image_url = specifications['image']['url']
         docker_client = biosimulators_utils.image.login_to_docker_registry(
             'docker.io',
             os.getenv('DOCKER_HUB_USERNAME'),
             os.getenv('DOCKER_HUB_TOKEN'))
-        image = biosimulators_utils.image.pull_docker_image(docker_client, original_image_url)
+        image = get_docker_image(docker_client, original_image_url, pull=True)
 
         # push image to BioSimulators namespace of Docker registry
         biosimulators_utils.image.login_to_docker_registry(
